@@ -360,7 +360,13 @@ def OpenGameplayOptionsWindow ():
 	GUIOPTControls.OptSlider (18042, 18017, HelpTextArea, Window, 1, 21, 17143, 'Tooltips', DisplayHelpTooltipDelay, 10)
 	GUIOPTControls.OptSlider (18042, 18018, HelpTextArea, Window, 2, 22, 17144, 'Mouse Scroll Speed', DisplayHelpMouseScrollingSpeed, 5)
 	GUIOPTControls.OptSlider (18042, 18019, HelpTextArea, Window, 3, 23, 17145, 'Keyboard Scroll Speed', None, 5)
+
 	GUIOPTControls.OptSlider (18042, 18020, HelpTextArea, Window, 12, 24, 13911, 'Difficulty Level', None, 0)
+	if GemRB.GetVar ("Nightmare Mode") == 1:
+		# lock the slider
+#		Slider = Window.GetControl (12)
+#		Slider.SetDisabled (True)
+		pass
 
 	GUIOPTControls.OptCheckbox (18042, 18021, HelpTextArea, Window, 14, 25, 13697, 'Always Dither')
 	GUIOPTControls.OptCheckbox (18042, 18023, HelpTextArea, Window, 19, 27, 17182, 'Gore')
@@ -368,7 +374,7 @@ def OpenGameplayOptionsWindow ():
 	GUIOPTControls.OptCheckbox (18042, 20619, HelpTextArea, Window, 47, 46, 20618, 'Weather')
 	if GameCheck.IsBG2():
 		GUIOPTControls.OptCheckbox (18042, 2242, HelpTextArea, Window, 50, 48, 2241, 'Heal Party on Rest')
-	elif GameCheck.IsIWD2():
+	elif GameCheck.IsIWD2() or GameCheck.IsIWD():
 		GUIOPTControls.OptCheckbox (18042, 15136, HelpTextArea, Window, 50, 49, 17378, 'Maximum HP')
 
 	GUIOPTControls.OptButton (OpenFeedbackOptionsWindow, Window, 5, 17163)
@@ -624,6 +630,7 @@ def QuitGamePress ():
 		GemRB.Quit()
 		return
 
+	GemRB.SetVar ("SelectedWindow", 0)
 	CloseQuitMsgWindow()
 
 	GemRB.QuitGame ()
