@@ -236,14 +236,16 @@ def CloseItemInfoWindow ():
 	GUIINV.UpdateInventoryWindow ()
 	return
 
-def DisplayItem (itemresref, type):
+def DisplayItem (slotItem, type):
 	global ItemInfoWindow
 
-	item = GemRB.GetItem (itemresref)
+	item = GemRB.GetItem (slotItem["ItemResRef"])
 	ItemInfoWindow = Window = GemRB.LoadWindow (5)
 
 	if GameCheck.IsPST():
 		strrefs = [ 1403, 4256, 4255, 4251, 4252, 4254, 4279 ]
+	elif GameCheck.IsGemRBDemo ():
+		strrefs = [ 84, 105, 106, 104, 107, item["DialogName"], 108 ]
 	else:
 		strrefs = [ 11973, 14133, 11960, 19392, 17104, item["DialogName"], 17108 ]
 
@@ -259,10 +261,10 @@ def DisplayItem (itemresref, type):
 	Button = Window.GetControl (2)
 	if GameCheck.IsPST():
 		Button.SetFlags (IE_GUI_BUTTON_PICTURE | IE_GUI_BUTTON_NO_IMAGE, OP_SET)
-		Button.SetItemIcon (itemresref)
+		Button.SetItemIcon (slotItem["ItemResRef"])
 	else:
 		Button.SetFlags (IE_GUI_BUTTON_PICTURE, OP_OR)
-		Button.SetItemIcon (itemresref,0)
+		Button.SetItemIcon (slotItem["ItemResRef"], 0)
 	Button.SetState (IE_GUI_BUTTON_LOCKED)
 
 	#middle button
@@ -300,9 +302,9 @@ def DisplayItem (itemresref, type):
 		Button = Window.GetControl (7)
 		Button.SetFlags (IE_GUI_BUTTON_PICTURE | IE_GUI_BUTTON_CENTER_PICTURES | IE_GUI_BUTTON_NO_IMAGE, OP_OR)
 		if GameCheck.IsPST():
-			Button.SetItemIcon (itemresref, 1) # no DescIcon
+			Button.SetItemIcon (slotItem["ItemResRef"], 1) # no DescIcon
 		else:
-			Button.SetItemIcon (itemresref, 2)
+			Button.SetItemIcon (slotItem["ItemResRef"], 2)
 		Button.SetState (IE_GUI_BUTTON_LOCKED)
 
 	#right button
@@ -316,9 +318,15 @@ def DisplayItem (itemresref, type):
 	container = (type&1) and (item["Function"]&ITM_F_CONTAINER)
 	dialog = (type&1) and (item["Dialog"]!="" and item["Dialog"]!="*")
 	familiar = (type&1) and (item["Type"] == 38)
+	# perhaps it's true everywhere, but it's definitely needed in pst
+	# and yes, the check is reversed, so the bit name is a misnomer in this case
+	if GameCheck.IsPST() and slotItem["Flags"] & IE_INV_ITEM_CONVERSABLE:
+		dialog = False
+		drink = True # "Use"
+
 	if drink:
 		Button.SetText (strrefs[3])
-		Button.SetEvent (IE_GUI_BUTTON_ON_PRESS, DrinkItemWindow)
+		Button.SetEvent (IE_GUI_BUTTON_ON_PRESS, ConsumeItem)
 	elif read:
 		Button.SetText (strrefs[4])
 		Button.SetEvent (IE_GUI_BUTTON_ON_PRESS, ReadItemWindow)
@@ -391,7 +399,7 @@ def OpenItemInfoWindow (slot = None):
 		value = 1
 	else:
 		value = 3
-	DisplayItem (slot_item["ItemResRef"], value)
+	DisplayItem (slot_item, value)
 	return
 
 #auto identify when lore is high enough
@@ -414,7 +422,7 @@ def OpenGroundItemInfoWindow ():
 		value = 0
 	else:
 		value = 2
-	DisplayItem(slot_item["ItemResRef"], value)
+	DisplayItem(slot_item, value)
 	return
 
 # TODO: implement, reuse OpenItemAmountWindow, but be careful about any other uses of ItemButton
@@ -487,13 +495,19 @@ def OpenItemAmountWindow ():
 
 	# Done
 	Button = Window.GetControl (2)
-	Button.SetText (11973)
+	if GameCheck.IsGemRBDemo ():
+		Button.SetText (84)
+	else:
+		Button.SetText (11973)
 	Button.SetEvent (IE_GUI_BUTTON_ON_PRESS, DragItemAmount)
 	Button.SetFlags (IE_GUI_BUTTON_DEFAULT, OP_OR)
 
 	# Cancel
 	Button = Window.GetControl (1)
-	Button.SetText (13727)
+	if GameCheck.IsGemRBDemo ():
+		Button.SetText (103)
+	else:
+		Button.SetText (13727)
 	Button.SetEvent (IE_GUI_BUTTON_ON_PRESS, OpenItemAmountWindow)
 	Button.SetFlags (IE_GUI_BUTTON_CANCEL, OP_OR)
 
@@ -548,7 +562,10 @@ def UpdateSlot (pc, slot):
 			Button.SetTooltip ("")
 			itemname = ""
 		else:
-			Button.SetBAM (SlotType["ResRef"],0,0)
+			if SlotType["Flags"] & 2:
+				Button.SetPicture (SlotType["ResRef"])
+			else:
+				Button.SetBAM (SlotType["ResRef"], 0, 0)
 			Button.SetTooltip (SlotType["Tip"])
 
 		Button.SetEvent (IE_GUI_BUTTON_ON_PRESS, None)
@@ -647,10 +664,12 @@ def GetColor():
 	GUIINV.InventoryWindow.SetVisible (WINDOW_GRAYED) #darken it
 	ColorPicker=GemRB.LoadWindow (3)
 	GemRB.SetVar ("Selected",-1)
-	if GameCheck.IsIWD2():
+	if GameCheck.IsIWD2 () or GameCheck.IsGemRBDemo ():
 		Button = ColorPicker.GetControl (35)
 		Button.SetEvent (IE_GUI_BUTTON_ON_PRESS, CancelColor)
-		Button.SetText(13727)
+		Button.SetText (103)
+		if GameCheck.IsIWD2 ():
+			Button.SetText (13727)
 
 	for i in range (34):
 		Button = ColorPicker.GetControl (i)
@@ -681,13 +700,14 @@ def ReleaseFamiliar ():
 	CloseItemInfoWindow ()
 	return
 
-def DrinkItemWindow ():
+def ConsumeItem ():
 	"""Drink the potion"""
 
 	pc = GemRB.GameGetSelectedPCSingle ()
 	slot = GemRB.GetVar ("ItemButton")
 	# the drink item header is always the first
-	GemRB.UseItem (pc, slot, 0)
+	# pst also requires forcing the target (eg. clot charms), which doesn't hurt elsewhere
+	GemRB.UseItem (pc, slot, 0, 5)
 	CloseItemInfoWindow ()
 	return
 
@@ -965,6 +985,8 @@ def UpdateInventorySlot (pc, Button, Slot, Type, Equipped=False):
 	if Slot == None:
 		Button.SetFlags (IE_GUI_BUTTON_PICTURE, OP_NAND)
 		tooltips = { "inventory": 12013, "ground": 12011, "container": "" }
+		if GameCheck.IsGemRBDemo ():
+			tooltips = { "inventory": 82, "ground": 83, "container": "" }
 		Button.SetTooltip (tooltips[Type])
 		Button.EnableBorder (0, 0)
 		Button.EnableBorder (1, 0)
@@ -973,7 +995,7 @@ def UpdateInventorySlot (pc, Button, Slot, Type, Equipped=False):
 
 	item = GemRB.GetItem (Slot['ItemResRef'])
 	identified = Slot["Flags"] & IE_INV_ITEM_IDENTIFIED
-	magical = Slot["Flags"] & IE_INV_ITEM_MAGICAL > 0
+	magical = item["Enchantment"] > 0
 
 	# MaxStackAmount holds the *maximum* item count in the stack while Usages0 holds the actual
 	if item["MaxStackAmount"] > 1:
