@@ -19,33 +19,34 @@
 
 import GemRB
 import GameCheck
-import CommonTables
 import GUICommon
 import Spellbook
+import CommonTables
 from GUIDefines import *
 from ie_stats import *
-from ie_restype import RES_BAM
 
 # storage variables
 pc = 0
 chargen = 0
 KitMask = 0
+Class = 0
 
 # basic spell selection
 SpellsWindow = 0		# << spell selection window
-#SpellKnownTable = 0		# << known spells per level (table)
 DoneButton = 0			# << done/next button
 SpellsTextArea = 0		# << spell description area
 SpellsSelectPointsLeft = [0]*9	# << spell selections left per level
 Spells = [0]*9			# << spells learnable per level
 SpellTopIndex = 0		# << scroll bar index
 SpellBook = []			# << array containing all the spell indexes to learn
-MemoBook = [0]*24			# array containing all the spell indexes to memorize
+ButtonCount = 24		# number of spell slots in the window
+MemoBook = [0]*ButtonCount			# array containing all the spell indexes to memorize
 Memorization = 0			# marker for the memorisation part
 SpellLevel = 0			# << current level of spells
 SpellStart = 0			# << starting id of the spell list
 SpellPointsLeftLabel = 0	# << label indicating the number of points left
 EnhanceGUI = 0			# << scrollbars and extra spell slot for sorcs on LU
+BonusPoints = [0]*9		# bonus learning/memo points
 
 # chargen only
 SpellsPickButton = 0		# << button to select random spells
@@ -72,11 +73,11 @@ def OpenSpellsWindow (actor, table, level, diff, kit=0, gen=0, recommend=True, b
 	recommend is used in bg2 for spell recommendation / autopick."""
 
 	global SpellsWindow, DoneButton, SpellsSelectPointsLeft, Spells, chargen, SpellPointsLeftLabel
-	global SpellsTextArea, SpellsKnownTable, SpellTopIndex, SpellBook, SpellLevel, pc, SpellStart
-	global KitMask, EnhanceGUI, Memorization, SpellBookType, SpellsPickButton
+	global SpellsTextArea, SpellTopIndex, SpellBook, SpellLevel, pc, SpellStart, BonusPoints
+	global KitMask, EnhanceGUI, Memorization, SpellBookType, SpellsPickButton, ButtonCount, Class
 
 	#enhance GUI?
-	if (GemRB.GetVar("GUIEnhancements")&GE_SCROLLBARS):
+	if (GemRB.GetVar("GUIEnhancements")&GE_SCROLLBARS) and not IWD2:
 		EnhanceGUI = 1
 
 	# save our pc
@@ -92,13 +93,15 @@ def OpenSpellsWindow (actor, table, level, diff, kit=0, gen=0, recommend=True, b
 	if IWD2:
 		# save the spellbook type (class) that corresponds to our table
 		SpellBookType = booktype
+		if not chargen:
+			ButtonCount = 30
 
 	# make sure there is an entry at the given level (bard)
-	SpellsKnownTable = GemRB.LoadTable (table)
-	if not SpellsKnownTable.GetValue (str(level), str(1), GTV_INT):
+	SpellLearnTable = table
+	SpellsToMemoTable = GemRB.LoadTable (table)
+	if not SpellsToMemoTable.GetValue (str(level), str(1), GTV_INT):
 		if chargen:
 			if GameCheck.IsBG2():
-				# HACK
 				GemRB.SetNextScript("GUICG6")
 			elif GameCheck.IsBG1():
 				# HACK
@@ -137,9 +140,14 @@ def OpenSpellsWindow (actor, table, level, diff, kit=0, gen=0, recommend=True, b
 			SpellsPickButton.SetText(34210)
 	else:
 		SpellsWindow = GemRB.LoadWindow (8)
-		DoneButton = SpellsWindow.GetControl (28)
-		SpellsTextArea = SpellsWindow.GetControl(26)
-		SpellPointsLeftLabel = SpellsWindow.GetControl (0x10000018)
+		if IWD2:
+			DoneButton = SpellsWindow.GetControl (33)
+			SpellsTextArea = SpellsWindow.GetControl(30)
+			SpellPointsLeftLabel = SpellsWindow.GetControl (0x10000022)
+		else:
+			DoneButton = SpellsWindow.GetControl (28)
+			SpellsTextArea = SpellsWindow.GetControl(26)
+			SpellPointsLeftLabel = SpellsWindow.GetControl (0x10000018)
 		if(EnhanceGUI):
 			SpellsWindow.CreateScrollBar (1000, 290,142, 16,252)
 			HideUnhideScrollBar(1)
@@ -151,35 +159,64 @@ def OpenSpellsWindow (actor, table, level, diff, kit=0, gen=0, recommend=True, b
 	GemRB.SetVar ("SpellTopIndex", 0)
 	Memorization = 0
 	Class = GemRB.GetPlayerStat (pc, IE_CLASS)
+	if IWD2 and not chargen:
+		LUClass = GemRB.GetVar ("LUClass")
+		LUClassName = CommonTables.Classes.GetRowName (LUClass)
+		LUClassID = CommonTables.Classes.GetValue (LUClassName, "ID")
+		Class = LUClassID
 
 	# the done button also doubles as a next button
 	DoneButton.SetState(IE_GUI_BUTTON_DISABLED)
 	DoneButton.SetEvent(IE_GUI_BUTTON_ON_PRESS, SpellsDonePress)
 	DoneButton.SetText(11973)
 	DoneButton.SetFlags(IE_GUI_BUTTON_DEFAULT, OP_OR)
-		
+
+	# adjust the table for the amount of spells available for learning for free
+	# bg2 had SPLSRCKN, iwd2 also SPLBRDKN, but all the others lacked the tables
+	if SpellLearnTable == "MXSPLSOR":
+		SpellLearnTable = "SPLSRCKN"
+	elif SpellLearnTable == "MXSPLBRD":
+		SpellLearnTable = "SPLBRDKN"
+	# ... which is also important for mages during chargen and then never again
+	elif SpellLearnTable == "MXSPLWIZ":
+		SpellLearnTable = "SPLWIZKN"
+	else:
+		print "OpenSpellsWindow: unhandled spell learning type encountered, falling back to memo table:", table
+	SpellLearnTable = GemRB.LoadTable (SpellLearnTable)
+
+	CastingStatValue = 0
+	if IWD2:
+		# mxsplbon.2da is handled in core, but does also affect learning, at least in chargen
+		BonusSpellTable = GemRB.LoadTable ("mxsplbon")
+		ClassRowName = GUICommon.GetClassRowName (pc)
+		CastingStat = CommonTables.ClassSkills.GetValue (ClassRowName, "CASTING", GTV_INT)
+		CastingStatValue = GemRB.GetPlayerStat (pc, CastingStat)
+
 	AlreadyShown = 0
 	for i in range (9):
 		# make sure we always have a value to minus (bards)
-		SecondPoints = SpellsKnownTable.GetValue (str(level-diff), str(i+1), GTV_INT)
-		if not SecondPoints:
-			SecondPoints = 0
+		SecondPoints = SpellsToMemoTable.GetValue (str(level-diff), str(i+1), GTV_INT)
 
 		# make sure we get more spells of each class before continuing
-		SpellsSelectPointsLeft[i] = SpellsKnownTable.GetValue (str(level), str(i+1), GTV_INT) - SecondPoints
+		SpellsSelectPointsLeft[i] = SpellsToMemoTable.GetValue (str(level), str(i+1), GTV_INT) - SecondPoints
 		if SpellsSelectPointsLeft[i] <= 0:
 			continue
-		elif chargen and KitMask != 0x4000 and (not IWD2 or Class == 11):
+
+		SpellsSelectPointsLeft[i] = SpellLearnTable.GetValue (str(level), str(i+1), GTV_INT)
+		# luckily the bonus applies both to learning and memorization
+		if IWD2 and chargen:
+			BonusPoints[i] = BonusSpellTable.GetValue (str(CastingStatValue), str(i+1), GTV_INT)
+			SpellsSelectPointsLeft[i] += BonusPoints[i]
+
+		if SpellsSelectPointsLeft[i] <= 0:
+			continue
+		elif chargen and KitMask != 0x4000 and (not IWD2 or SpellBookType == IE_IWD2_SPELL_WIZARD):
 			# specialists get an extra spell per level
 			SpellsSelectPointsLeft[i] += 1
-
-		# chargen character seem to get more spells per level (this is kinda dirty hack)
-		# except sorcerers
-		if chargen and Class != 19 and not IWD2:
-			SpellsSelectPointsLeft[i] += 1
+			BonusPoints[i] += 1
 
 		# get all the spells of the given level
-		Spells[i] = Spellbook.GetMageSpells (KitMask, GemRB.GetPlayerStat (pc, IE_ALIGNMENT), i+1)
+		Spells[i] = Spellbook.GetMageSpells (KitMask, GemRB.GetPlayerStat (pc, IE_ALIGNMENT), i+1, Class)
 
 		# dump all the spells we already know
 		NumDeleted = 0
@@ -201,13 +238,13 @@ def OpenSpellsWindow (actor, table, level, diff, kit=0, gen=0, recommend=True, b
 #				ScrollBar.SetDefaultScrollBar ()
 
 				# only scroll if we have more than 24 spells or 25 if extra 25th spell slot is available in sorcs LevelUp
-				if len (Spells[i]) > ( 24 + ExtraSpellButtons() ):
+				if len (Spells[i]) > ( ButtonCount + ExtraSpellButtons() ):
 					ScrollBar.SetEvent (IE_GUI_SCROLLBAR_ON_CHANGE, ShowSpells)
 					HideUnhideScrollBar(0)
 					if chargen:
-						ScrollBar.SetVarAssoc ("SpellTopIndex", GUICommon.ceildiv ( ( len (Spells[i])-24 ) , 6 ) + 1 )
+						ScrollBar.SetVarAssoc ("SpellTopIndex", GUICommon.ceildiv ( ( len (Spells[i])-ButtonCount ) , 6 ) + 1 )
 					else: #there are five rows of 5 spells in level up of sorcs
-						ScrollBar.SetVarAssoc ("SpellTopIndex", GUICommon.ceildiv ( ( len (Spells[i])-25 ) , 5 ) + 1 )
+						ScrollBar.SetVarAssoc ("SpellTopIndex", GUICommon.ceildiv ( ( len (Spells[i])-ButtonCount-1 ) , 5 ) + 1 )
 				else:
 					ScrollBar.SetEvent (IE_GUI_SCROLLBAR_ON_CHANGE, None)
 					ScrollBar.SetVarAssoc ("SpellTopIndex", 0)
@@ -242,13 +279,16 @@ def SpellsDonePress ():
 			if i:
 				GemRB.MemorizeSpell(pc, SpellBookType, SpellLevel, i-1, 1)
 		SpellBook = []
-		MemoBook = [0]*24
+		MemoBook = [0]*ButtonCount
 
 	# save all the spells
 	if not Memorization:
 		for i in range (len (Spells[SpellLevel])):
 			if SpellBook[i]: # we need to learn this spell
-				GemRB.LearnSpell (pc, Spells[SpellLevel][i][0])
+				if IWD2:
+					GemRB.LearnSpell (pc, Spells[SpellLevel][i][0], 0, 1<<SpellBookType)
+				else:
+					GemRB.LearnSpell (pc, Spells[SpellLevel][i][0])
 
 		# check to see if we need to update again
 		for i in range (SpellLevel+1, 9):
@@ -262,12 +302,12 @@ def SpellsDonePress ():
 				if (EnhanceGUI):
 					# setup the scrollbar
 					ScrollBar = SpellsWindow.GetControl (1000)
-					if len (Spells[i]) > ( 24 + ExtraSpellButtons() ):
+					if len (Spells[i]) > ( ButtonCount + ExtraSpellButtons() ):
 						HideUnhideScrollBar(0)
 						if chargen:
-							ScrollBar.SetVarAssoc ("SpellTopIndex", GUICommon.ceildiv ( ( len (Spells[i])-24 ) , 6 ) + 1 )
+							ScrollBar.SetVarAssoc ("SpellTopIndex", GUICommon.ceildiv ( ( len (Spells[i])-ButtonCount ) , 6 ) + 1 )
 						else:
-							ScrollBar.SetVarAssoc ("SpellTopIndex", GUICommon.ceildiv ( ( len (Spells[i])-25 ) , 5 ) + 1 )
+							ScrollBar.SetVarAssoc ("SpellTopIndex", GUICommon.ceildiv ( ( len (Spells[i])-ButtonCount-1 ) , 5 ) + 1 )
 					else:
 						ScrollBar.SetVarAssoc ("SpellTopIndex", 0)
 						HideUnhideScrollBar(1)
@@ -279,12 +319,12 @@ def SpellsDonePress ():
 
 		# bg1 lets you memorize spells too (iwd too, but it does it by itself)
 		if chargen and sum(MemoBook) == 0 and \
-		(GameCheck.IsBG1() or (IWD2 and SpellBookType != IE_IWD2_SPELL_SORCERER)):
+		(GameCheck.IsBG1() or (IWD2 and SpellBookType == IE_IWD2_SPELL_WIZARD)):
 			SpellLevel = 0
-			SpellsSelectPointsLeft[SpellLevel] = 1
-			if KitMask != 0x4000:
-				# specialists get an extra spell per level
-				SpellsSelectPointsLeft[SpellLevel] += 1
+			# bump it for specialists and iwd2 casters with high stats
+			SpellsSelectPointsLeft[SpellLevel] = 1 + BonusPoints[SpellLevel]
+			# FIXME: setting the proper count here breaks original characters, see #680
+			#GemRB.SetMemorizableSpellsCount (pc, SpellsSelectPointsLeft[SpellLevel], SpellBookType, SpellLevel)
 			DoneButton.SetState (IE_GUI_BUTTON_DISABLED)
 			Memorization = 1
 			ShowKnownSpells()
@@ -298,7 +338,6 @@ def SpellsDonePress ():
 	# move to the next script if this is chargen
 	if chargen:
 		if GameCheck.IsBG2():
-			# HACK
 			GemRB.SetNextScript("GUICG6")
 		elif GameCheck.IsBG1():
 			# HACK
@@ -306,6 +345,9 @@ def SpellsDonePress ():
 			next()
 		elif IWD2:
 			GemRB.SetNextScript("CharGen7")
+	elif IWD2:
+		import GUIREC
+		GUIREC.FinishLevelUp ()
 
 	return
 
@@ -313,15 +355,15 @@ def ShowKnownSpells ():
 	"""Shows the viewable 24 spells."""
 
 	j = RowIndex()
-	Spells[SpellLevel] = Spellbook.GetMageSpells (KitMask, GemRB.GetPlayerStat (pc, IE_ALIGNMENT), SpellLevel+1)
+	Spells[SpellLevel] = Spellbook.GetMageSpells (KitMask, GemRB.GetPlayerStat (pc, IE_ALIGNMENT), SpellLevel+1, Class)
 
 	# reset the title
 	#17224 for priest spells
 	Title = SpellsWindow.GetControl (0x10000000)
 	Title.SetText(17189)
 
-	# we have a grid of 24 spells
-	for i in range (24):
+	# we have a grid of 24 (usually) spells
+	for i in range (ButtonCount):
 		# ensure we can learn this many spells
 		SpellButton = SpellsWindow.GetControl (i+SpellStart)
 		if i + j >= len (SpellBook) or not SpellBook[i+j]:
@@ -353,6 +395,10 @@ def ShowKnownSpells ():
 	GemRB.SetToken("number", str(SpellsSelectPointsLeft[SpellLevel]))
 	SpellsTextArea.SetText(17253)
 
+	if SpellsPickButton == 0:
+		# no recommendations at all
+		return
+
 	if Memorization == 1:
 		SpellsPickButton.SetState (IE_GUI_BUTTON_DISABLED)
 	else:
@@ -401,7 +447,7 @@ def ShowSpells ():
 	j = RowIndex()
 
 	# we have a grid of 24 spells
-	for i in range (24 + ExtraSpellButtons()):
+	for i in range (ButtonCount + ExtraSpellButtons()):
 		# ensure we can learn this many spells
 		SpellButton = SpellsWindow.GetControl (i+SpellStart)
 		if i + j >= len (Spells[SpellLevel]):
@@ -445,6 +491,10 @@ def ShowSpells ():
 
 	GemRB.SetToken("number", str(SpellsSelectPointsLeft[SpellLevel]))
 	SpellsTextArea.SetText(17250)
+	if SpellsWindow.HasControl (0x10000000):
+		LevelLabel = SpellsWindow.GetControl (0x10000000)
+		GemRB.SetToken ("SPELLLEVEL", str(SpellLevel+1))
+		LevelLabel.SetText (10345)
 
 	return
 
@@ -522,7 +572,7 @@ def ShowSelectedSpells ():
 	k = RowIndex()
 
 	# mark all of the spells picked thus far
-	for j in range (24 + ExtraSpellButtons()):
+	for j in range (ButtonCount + ExtraSpellButtons()):
 		if j + k >= len (SpellBook): # make sure we don't call unavailable indexes
 			break
 		if (SpellBook[j+k] and not Memorization) or (Memorization and MemoBook[j+k]): # selected
@@ -602,7 +652,7 @@ def HasSpecialistSpell ():
 	"""Determines if specialist requirements have been met.
 
 	Always returns true if the mage is not a specialist.
-	Returns true only if the specialists knows at least one spell from thier
+	Returns true only if the specialists knows at least one spell from their
 	school."""
 
 	# always return true for non-kitted classed
@@ -637,6 +687,8 @@ def RowIndex ():
 	SpellTopIndex = GemRB.GetVar ("SpellTopIndex")
 	if chargen:
 		return ( SpellTopIndex + 1 ) * 6 - 6
+	elif IWD2: # 30 during level-up
+		return ( SpellTopIndex + 1 ) * 6 - 6
 	elif EnhanceGUI:
 		return ( SpellTopIndex + 1 ) * 5 - 5
 	else:
