@@ -230,7 +230,7 @@ IE_PROFICIENCY2HANDED 		= 111
 IE_PROFICIENCYSWORDANDSHIELD 	= 112
 IE_PROFICIENCYSINGLEWEAPON 	= 113	
 IE_PROFICIENCY2WEAPON 		= 114  			
-IE_EXTRAPROFICIENCY1 		= 115
+IE_PROFICIENCYCLUB		= 115
 IE_EXTRAPROFICIENCY2 		= 116
 IE_EXTRAPROFICIENCY3 		= 117
 IE_EXTRAPROFICIENCY4 		= 118
