@@ -72,17 +72,20 @@ import NewLife
 from GUIDefines import *
 from ie_stats import *
 import GUIWORLD
+import LUSkillsSelection
 
 ###################################################
 LevelUpWindow = None
 RecordsWindow = None
 InformationWindow = None
 BiographyWindow = None
+PauseState = None
 
 ###################################################
 def OpenRecordsWindow ():
 	global RecordsWindow
 	global StatTable
+	global PauseState
 
 	StatTable = GemRB.LoadTable("abcomm")
 	
@@ -97,8 +100,12 @@ def OpenRecordsWindow ():
 		GUICommonWindows.SetSelectionChangeHandler (None)
 
 		GemRB.UnhideGUI ()
+		GemRB.GamePause (PauseState, 3)
 		return	
 
+	PauseState = GemRB.GamePause (3, 1)
+	GemRB.GamePause (1, 3)
+
 	GemRB.HideGUI ()
 	GemRB.LoadWindowPack ("GUIREC")
 	RecordsWindow = Window = GemRB.LoadWindow (3)
@@ -243,11 +250,19 @@ def UpdateRecordsWindow ():
 		Label.SetText (str (stats[i]))
 
 	# race
-	# HACK: for some strange reason, Morte's race is 1 (Human), instead of 45 (Morte)
-	print "species: %d  race: %d" %(GemRB.GetPlayerStat (pc, IE_SPECIES), GemRB.GetPlayerStat (pc, IE_RACE))
-	#be careful, some saves got this field corrupted
+
+	# this is -1 to lookup the value in the table
 	race = GemRB.GetPlayerStat (pc, IE_SPECIES) - 1
 
+	# workaround for original saves that don't have the characters species stat set properly
+	if race == -1:
+		if GemRB.GetPlayerStat (pc, IE_SPECIFIC) == 3: # Vhailor
+			race = 50 # Changes from GHOST to RESTLESS_SPIRIT
+		elif  GemRB.GetPlayerStat (pc, IE_SPECIFIC) == 9: # Morte
+			race = 44 # Changes from HUMAN to MORTE. Morte is Morte :)
+		else:
+			race = GemRB.GetPlayerStat (pc, IE_RACE) - 1
+
 	text = CommonTables.Races.GetValue (race, 0)
 	
 	Label = Window.GetControl (0x10000014)
@@ -829,7 +844,7 @@ def OpenBiographyWindow ():
 
 	BioTable = GemRB.LoadTable ("bios")
 	Specific = GemRB.GetPlayerStat (pc, IE_SPECIFIC)
-	BioText = int (BioTable.GetValue (BioTable.GetRowName (Specific+1), 'BIO'))
+	BioText = int (BioTable.GetValue (BioTable.GetRowName (Specific), 'BIO'))
 
 	TextArea = Window.GetControl (0)
 	TextArea.SetText (BioText)
@@ -854,10 +869,10 @@ def AcceptLevelUp():
 	GemRB.SetPlayerStat (pc, IE_SAVEVSPOLY, SavThrows[2])
 	GemRB.SetPlayerStat (pc, IE_SAVEVSBREATH, SavThrows[3])
 	GemRB.SetPlayerStat (pc, IE_SAVEVSSPELL, SavThrows[4])
-	oldhp = GemRB.GetPlayerStat (pc, IE_HITPOINTS, 1)
-	GemRB.SetPlayerStat (pc, IE_HITPOINTS, HPGained+oldhp)
 	oldhp = GemRB.GetPlayerStat (pc, IE_MAXHITPOINTS, 1)
 	GemRB.SetPlayerStat (pc, IE_MAXHITPOINTS, HPGained+oldhp)
+	oldhp = GemRB.GetPlayerStat (pc, IE_HITPOINTS, 1)
+	GemRB.SetPlayerStat (pc, IE_HITPOINTS, HPGained+oldhp)
 	#increase weapon proficiency if needed
 	if WeapProfType!=-1:
 		GemRB.SetPlayerStat (pc, WeapProfType, CurrWeapProf + WeapProfGained )
@@ -871,8 +886,18 @@ def AcceptLevelUp():
 		GemRB.SetPlayerStat (pc, IE_LEVEL, GemRB.GetPlayerStat (pc, IE_LEVEL)+NumOfPrimLevUp)
 		if avatar_header['SecoLevel'] != 0:
 			GemRB.SetPlayerStat (pc, IE_LEVEL2, GemRB.GetPlayerStat (pc, IE_LEVEL2)+NumOfSecoLevUp)
+	
+	LUSkillsSelection.SkillsSave (pc)
 	UpdateRecordsWindow ()
 
+def RedrawSkills():
+	DoneButton = LevelUpWindow.GetControl(0)
+
+	if GemRB.GetVar ("SkillPointsLeft") == 0:
+		DoneButton.SetState(IE_GUI_BUTTON_ENABLED)
+	else:
+		DoneButton.SetState(IE_GUI_BUTTON_DISABLED)
+	return
 
 def OpenLevelUpWindow ():
 	global LevelUpWindow
@@ -932,13 +957,13 @@ def OpenLevelUpWindow ():
 		# Searching for the column name where value is 1
 		for i in range (5):
 			WeapProfName = ClasWeapTable.GetRowName (i)
-			value = ClasWeapTable.GetValue (AvatarName, WeapProfName)
+			value = ClasWeapTable.GetValue (WeapProfName, AvatarName)
 			if value == 1:
 				WeapProfType = i
 				break
 
 	if WeapProfType!=-1:
-		CurrWeapProf = GemRB.GetPlayerStat (pc, IE_WEAPPROF+WeapProfType)
+		CurrWeapProf = GemRB.GetPlayerStat (pc, IE_PROFICIENCYBASTARDSWORD + WeapProfType)
 
 	# Recording this avatar's current proficiency level
 	# Since Nameless one is not covered, hammer and club can't occur
@@ -975,9 +1000,8 @@ def OpenLevelUpWindow ():
 	Label = Window.GetControl (0x1000000E)
 	Label.SetText (str (GemRB.GetPlayerStat (pc, IE_LOCKPICKING)) + '%')
 	# Plus and Minus buttons
-	for i in range (8):
-		Button = Window.GetControl (16 + i)
-		Button.SetState (IE_GUI_BUTTON_LOCKED)
+	LUSkillsSelection.SetupSkillsWindow (pc, LUSkillsSelection.LUSKILLS_TYPE_LEVELUP, LevelUpWindow, RedrawSkills, [0,0,0], [1,1,1], 0, False)
+	RedrawSkills()
 
 	# Is avatar multi-class?
 	if avatar_header['SecoLevel'] == 0:
@@ -1172,7 +1196,7 @@ def OpenLevelUpWindow ():
 	# Displaying level up info
 	overview = ""
 	if CurrWeapProf!=-1 and WeapProfGained>0:
-		overview = overview + '+' + str (WeapProfGained) + ' ' + GemRB.GetString (WeapProfDispStr) + '\n'
+		overview = overview + GemRB.GetString (38715) + '\n' + '+' + str (WeapProfGained) + '\n'
 
 	overview = overview + str (HPGained) + " " + GemRB.GetString (38713) + '\n'
 	overview = overview + str (ConHPBon) + " " + GemRB.GetString (38727) + '\n'
@@ -1236,7 +1260,7 @@ def HasGainedWeapProf (pc, currProf, currLevel, Class):
 	#hardcoded limit is 4
 	if currProf>3:
 		return False
-	if CurrProf>(currLevel-1)/3:
+	if currProf > (currLevel - 1) / 3:
 		return False
 	return True
 
